@@ -1,5 +1,5 @@
 # sqlalchemy/events.py
-# Copyright (C) 2005-2021 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2020 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -216,12 +216,6 @@ class DDLEvents(event.Events):
 
         """
 
-    def _sa_event_column_added_to_pk_constraint(self, const, col):
-        """internal event hook used for primary key naming convention
-        updates.
-
-        """
-
     def column_reflect(self, inspector, table, column_info):
         """Called for each unit of 'column info' retrieved when
         a :class:`_schema.Table` is being reflected.
